@@ -1,20 +1,52 @@
 import subprocess
 import sys
 import os
+import gdown
+
+BlazeFaceURL       = 'https://drive.google.com/uc?id=1FhJrGLBnnRw_nq0p58NUzlN2rZI9BAQa'
+AnchorsURL         = 'https://drive.google.com/uc?id=1oqK5yz5ZaWjLP9O_eXhvGL9RD6hOyS6d'
+pytorchCVURL       = 'https://drive.google.com/uc?id=18cBhKpkRflQmyXCVjy1DtVLIUnLPo2bO'
+ResNextModelURL    = 'https://drive.google.com/uc?id=1siAcM9uTEoLEeqKFxq5h-hjs4NoHS0SU'
+XcePtionModelURL   = 'https://drive.google.com/uc?id=1--68J6Ipny937AFjJ_AKjhFXFnvnGecV'
+
+pytorchcv          = 'pytorchcv-0.0.55-py2.py3-none-any.whl'
+ResNextModel       = 'resnext.pth'
+XcePtionModel      = 'xception.pth'
+BlazeFaceModel     = 'blazeface.pth'
+AnchorsNpy         = 'anchors.npy'
+
+gdown.download(pytorchCVURL, pytorchcv, quiet=False)
+gdown.download(ResNextModelURL, ResNextModel, quiet=False)
+gdown.download(XcePtionModelURL, XcePtionModel, quiet=False)
+gdown.download(BlazeFaceURL, BlazeFaceModel, quiet=False)
+gdown.download(AnchorsURL, AnchorsNpy, quiet=False)
+
+
+output  = '.\\pytorchcv-0.0.55-py2.py3-none-any.whl'
+output1 = '.\\resnext.pth'
+output2 = '.\\xception.pth'
+output3 = '.\\blazeface.pth'
+output4 = '.\\anchors.npy'
+
+__location__  = os.path.realpath(os.path.join(os.getcwd(), os.path.dirname(output)))
+__location1__ = os.path.realpath(os.path.join(os.getcwd(), os.path.dirname(output1)))
+__location2__ = os.path.realpath(os.path.join(os.getcwd(), os.path.dirname(output2)))
+__location3__ = os.path.realpath(os.path.join(os.getcwd(), os.path.dirname(output3)))
+__location4__ = os.path.realpath(os.path.join(os.getcwd(), os.path.dirname(output4)))
+
+pytorchCVPackage     = os.path.join(__location__, 'pytorchcv-0.0.55-py2.py3-none-any.whl')
+ResNextModelWeights  = os.path.join(__location1__, 'resnext.pth')
+XcePtionModelWeights = os.path.join(__location2__, 'xception.pth')
+blazefaceM           = os.path.join(__location3__, 'blazeface.pth')
+anchorsN             = os.path.join(__location4__, 'anchors.npy')
+
 def install(package):
+  try:
     subprocess.check_call([sys.executable, "-m", "pip", "install", package])
+  except subprocess.CalledProcessError as e:
+    raise RuntimeError("command '{}' return with error (code {}): {}".format(e.cmd, e.returncode, e.output))
 
-
-# __Packagelocation__ = os.path.realpath(os.path.join(os.getcwd(), os.path.dirname(".\\pytorchcv-0.0.55-py2.py3-none-any.whl")))
-# PackagePath = os.path.join(__Packagelocation__, "deepfake_detection","pytorchcv-0.0.55-py2.py3-none-any.whl")
-
-# __Blazefacelocation__ = os.path.realpath(os.path.join(os.getcwd(), os.path.dirname("blazeface.pth")))
-# BlazefacePath = os.path.join(__Blazefacelocation__, "deepfake_detection","blazeface.pth")
-
-# __Anchorslocation__ = os.path.realpath(os.path.join(os.getcwd(), os.path.dirname("anchors.npy")))
-# AnchorsPath = os.path.join(__Anchorslocation__, "deepfake_detection","anchors.npy")
-
-install('pytorchcv-0.0.55-py2.py3-none-any.whl')
+install(pytorchCVPackage)
 install("pytube")
 install("moviepy")
 install("youtube-dl")
@@ -38,15 +70,6 @@ warnings.filterwarnings("ignore")
 
 device = torch.device('cuda:0' if torch.cuda.is_available() else 'cpu')
 
-output1 = '.\\resnext.pth'
-output2= '.\\xception.pth'
-__location1__ = os.path.realpath(os.path.join(os.getcwd(), os.path.dirname(output1)))
-__location2__ = os.path.realpath(os.path.join(os.getcwd(), os.path.dirname(output2)))
-ResNextModelWeights = os.path.join(__location1__, 'resnext.pth')
-XcePtionModelWeights= os.path.join(__location2__, 'xception.pth')
-
-
-
 frames_per_video = 64 
 input_size_resnext = 224
 input_size_xception = 150
@@ -1009,8 +1032,8 @@ def overlap_similarity(box, other_boxes):
 
 #######################################################################
 facedet = BlazeFace().to(device)
-facedet.load_weights('blazeface.pth')
-facedet.load_anchors('anchors.npy')
+facedet.load_weights(blazefaceM)
+facedet.load_anchors(anchorsN)
 _ = facedet.train(False)
 
 
